import os
import random
import string
from flask import Flask

import data.document

def create_app():
	app = Flask(__name__)
	
	app.config.from_object('app_config')
	app.config.from_envvar('CONFIG_PATH')
	
	if len(app.config['ADMIN_PASSWORD']) < 8:
		raise Exception("Missing or insecure admin password, please update your configuration file")
		
	if not app.config['DEBUG'] and app.config['ADMIN_PASSWORD'] == "abcdefgh":
		raise Exception("Insecure admin password")
	
	# generate a new secret_key if needed, and store it in a file
	secret_key_path = app.config['DATA_ROOT_DIR'] + '/flask-secret-key'
	if not os.path.isfile(secret_key_path):
		new_secret_key = ''.join(random.SystemRandom().choice(string.ascii_letters + string.digits) for _ in range(20))
		with open(secret_key_path, 'wb') as f:
			f.write(new_secret_key.encode())
	with open(secret_key_path, 'rb') as f:
		secret_key = f.read().decode().replace('\n', '').replace('\r', '')
	if len(secret_key) < 20:
		raise Exception("Internal error: insecure secret key")
	app.secret_key = secret_key
	
	if app.config['BEHIND_REVERSE_PROXY']:
		from werkzeug.middleware.proxy_fix import ProxyFix
		app.wsgi_app = ProxyFix(app.wsgi_app)

	from api import api_document
	app.register_blueprint(api_document.bp)
	
	from web import web_document
	app.register_blueprint(web_document.bp)
	
	from web.admin import admin
	app.register_blueprint(admin.bp)
	
	from web.admin import admin_document
	app.register_blueprint(admin_document.bp)

	return app
